@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1997, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -733,8 +733,7 @@ public class PolicyParser {
         switch (lookahead) {
         case StreamTokenizer.TT_NUMBER:
             throw new ParsingException(st.lineno(), expect,
-                LocalizedMessage.getNonlocalized("number.") +
-                    String.valueOf(st.nval));
+                LocalizedMessage.getNonlocalized("number.") + st.nval);
         case StreamTokenizer.TT_EOF:
             LocalizedMessage localizedMsg = new LocalizedMessage
                 ("expected.expect.read.end.of.file.");
@@ -812,7 +811,7 @@ public class PolicyParser {
             break;
         default:
             throw new ParsingException(st.lineno(), expect,
-                               new String(new char[] {(char)lookahead}));
+                               String.valueOf((char)lookahead));
         }
         return value;
     }
@@ -826,8 +825,7 @@ public class PolicyParser {
             switch (lookahead) {
             case StreamTokenizer.TT_NUMBER:
                 throw new ParsingException(st.lineno(), ";",
-                        LocalizedMessage.getNonlocalized("number.") +
-                            String.valueOf(st.nval));
+                        LocalizedMessage.getNonlocalized("number.") + st.nval);
             case StreamTokenizer.TT_EOF:
                 throw new ParsingException(LocalizedMessage.getNonlocalized
                         ("expected.read.end.of.file."));
